Documentation
¶
Overview ¶
Package std provides an engine implementation backed by net/http.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bridge ¶
type Bridge struct {
// contains filtered or unexported fields
}
Bridge implements http.Handler, bridging net/http requests to stream.Handler.
type Engine ¶
type Engine struct {
// contains filtered or unexported fields
}
Engine wraps net/http.Server to implement the engine.Engine interface.
func (*Engine) Listen ¶
Listen starts the server and blocks until the context is canceled or an error occurs.
func (*Engine) Metrics ¶
func (e *Engine) Metrics() engine.EngineMetrics
Metrics returns a snapshot of engine metrics.
Click to show internal directories.
Click to hide internal directories.