Discover Packages
github.com/goceleris/celeris
internal
conn
package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 12, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package conn provides shared HTTP/1.1 and HTTP/2 connection handling.
CloseH2 cleans up H2 state.
ProcessH1 processes incoming H1 data, parsing requests and calling the handler.
The write callback is used to send response bytes back to the connection.
ProcessH2 processes incoming H2 data.
On first call, validates the client preface and sends server settings.
H1State holds per-connection H1 parsing state.
NewH1State creates a new H1 connection state.
type H2Config struct {
MaxConcurrentStreams uint32
InitialWindowSize uint32
MaxFrameSize uint32
}
H2Config holds H2 connection configuration.
H2State holds per-connection H2 state.
NewH2State creates a new H2 connection state.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.